# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Image'
        db.create_table(u'django_bootstrap_markdown_image', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('original', self.gf('django.db.models.fields.files.ImageField')(max_length=100)),
            ('description', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('timestamp', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
        ))
        db.send_create_signal(u'django_bootstrap_markdown', ['Image'])


    def backwards(self, orm):
        # Deleting model 'Image'
        db.delete_table(u'django_bootstrap_markdown_image')


    models = {
        u'django_bootstrap_markdown.image': {
            'Meta': {'ordering': "['-timestamp']", 'object_name': 'Image'},
            'description': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'original': ('django.db.models.fields.files.ImageField', [], {'max_length': '100'}),
            'timestamp': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'})
        }
    }

    complete_apps = ['django_bootstrap_markdown']


from django.contrib import admin
from imagekit.admin import AdminThumbnail
from django_bootstrap_markdown.models import Image


class ImageAdmin(admin.ModelAdmin):
    date_hierarchy = 'timestamp'
    list_display = ('admin_thumbnail', 'original', 'description')
    list_display_links = ['original']
    admin_thumbnail = AdminThumbnail(image_field='small')

admin.site.register(Image, ImageAdmin)



from django.forms import Textarea
from django.utils.safestring import mark_safe


class MarkdownInput(Textarea):
    def __init__(self, attrs=None, image_control=True):
        self.image_control = image_control

        default_attrs = {
            'class': 'form-control',
            'style': 'height: 400px; resize: none; font-family: "Courier New", Courier, "Lucida Sans Typewriter", "Lucida Typewriter", monospace; font-weight: bold;',
        }
        if attrs:
            default_attrs.update(attrs)

        super(Textarea, self).__init__(default_attrs)

    def render(self, name, value, attrs=None):
        textarea = Textarea.render(self, name, value)

        if self.image_control:
            image_control_markup = """
            <div class="pull-right">
                <button type="button" class="btn btn-sm btn-default markdown-image-btn">
                    <span class="glyphicon glyphicon-picture"></span>
                    Add Image
                </button>
            </div>
            """
        else:
            image_control_markup = ""

        markup = """
        <div class="row md-edit">
            <div class="col-sm-6">
                %s
                <h5 class="text-muted">Markdown</h5>
                %s
            </div>
            <div class="col-sm-6 hidden-xs">
                <h5 class="text-muted">Preview</h5>
                <div class="form-control preview" style="height: 400px; overflow: auto;"></div>
            </div>
        </div>
        """ % (image_control_markup, textarea)

        return mark_safe(markup)

    class Media:
        js = (
            '//cdnjs.cloudflare.com/ajax/libs/marked/0.2.9/marked.min.js',
            'js/jquery.textarea.min.js',
            'js/django_bootstrap_markdown_editor.js',
        )



from django.db import models
from imagekit.models import ImageSpecField
from imagekit.processors import ResizeToFill, ResizeToFit


class Image(models.Model):
    original = models.ImageField(upload_to='markdown/images/')
    large = ImageSpecField(
        source='original',
        processors=[ResizeToFit(750, 400)],
        options={'quality': 75}
    )
    medium = ImageSpecField(
        source='original',
        processors=[ResizeToFit(375, 400)],
        options={'quality': 75}
    )
    small = ImageSpecField(
        source='original',
        processors=[ResizeToFit(185, 400)],
        options={'quality': 75}
    )
    billboard = ImageSpecField(
        source='original',
        processors=[ResizeToFill(750, 300)],
        options={'quality': 75}
    )
    description = models.CharField(max_length=200)
    timestamp = models.DateTimeField(auto_now_add=True)

    class Meta:
        ordering = ['-timestamp']


from django import forms


class ImageForm(forms.Form):
    image = forms.ImageField()
    description = forms.CharField(
        required=False,
        widget=forms.TextInput(attrs={
            'class': 'form-control',
            'placeholder': 'a short description of the image for screen ' +
            'readers and search engines',
        })
    )
    size = forms.ChoiceField(
        widget=forms.RadioSelect,
        choices=(
            ('Billboard', 'Billboard'),
            ('Small', 'Small'),
            ('Medium', 'Medium'),
            ('Large', 'Large'),
            ('Original', 'Original'),
        ),
        initial = 'Billboard'
    )



from django.shortcuts import render
from django.contrib.auth.decorators import user_passes_test
from django_bootstrap_markdown.models import Image
from django_bootstrap_markdown.forms import ImageForm


def is_staff(user):
    return user.is_staff


@user_passes_test(is_staff)
def markdown_image(request):
    if request.method == 'POST':
        form = ImageForm(request.POST, request.FILES)
        if form.is_valid():
            image = Image()
            image.original = form.cleaned_data['image']
            image.description = form.cleaned_data['description']
            image.save()

            if form.cleaned_data['size'] == 'Small':
                thumbnail = image.small
            elif form.cleaned_data['size'] == 'Medium':
                thumbnail = image.medium
            elif form.cleaned_data['size'] == 'Large':
                thumbnail = image.large
            elif form.cleaned_data['size'] == 'Original':
                thumbnail = image.original
            else:
                thumbnail = image.billboard

            return render(request, 'markdown_image.html', {
                'form': form,
                'image': image,
                'thumbnail': thumbnail,
            })
    else:
        form = ImageForm()

    return render(request, 'markdown_image.html', {
        'form': form,
    })